#!/usr/bin/env bash
set -eu -o pipefail

__KAFKA_BASE="${1:-}"

if [ -z "$__KAFKA_BASE" ] || [ ! -d "$__KAFKA_BASE" ]; then
    echo "Existing base directory for storage required" >&2
    exit 1
fi

__KAFKA_CLUSTER_ID_FILE_PATH="${1}/kafka-cluster-id"
__KAFKA_KRAFT_CONFIG_FILE="reconfig-server.properties"
__KAFKA_KRAFT_CONFIG_DIR_PATH="${__KAFKA_BASE}/kafka-config/kraft"
__KAFKA_KRAFT_CONFIG_FILE_PATH="${__KAFKA_KRAFT_CONFIG_DIR_PATH}/${__KAFKA_KRAFT_CONFIG_FILE}"
__KAFKA_LOG_DIRS_PATH="${__KAFKA_BASE}/kafka-logs"

# runtime logs
export LOG_DIR="${__KAFKA_BASE}/logs"

if [ ! -e "$__KAFKA_CLUSTER_ID_FILE_PATH" ]; then
    /usr/share/java/kafka/bin/kafka-storage.sh random-uuid > "$__KAFKA_CLUSTER_ID_FILE_PATH"
fi

__KAFKA_CLUSTER_ID="$(cat "$__KAFKA_CLUSTER_ID_FILE_PATH")"
__KAFKA_DO_STORAGE_FORMAT=0

if [ ! -e "$__KAFKA_KRAFT_CONFIG_FILE_PATH" ]; then
    if [ ! -e "$(dirname "$__KAFKA_KRAFT_CONFIG_DIR_PATH")" ]; then
        mkdir --parents "$__KAFKA_KRAFT_CONFIG_DIR_PATH"
    fi
    cp "/usr/share/java/kafka/config/kraft/${__KAFKA_KRAFT_CONFIG_FILE}" "$__KAFKA_KRAFT_CONFIG_FILE_PATH"
    __KAFKA_DO_STORAGE_FORMAT=1
fi

__KAFKA_CURRENT_LOG_DIRS_PATH="$(grep '^log.dirs=' "$__KAFKA_KRAFT_CONFIG_FILE_PATH" | awk -F= '{ printf $2 }')"

if [ "$__KAFKA_CURRENT_LOG_DIRS_PATH" != "$__KAFKA_LOG_DIRS_PATH" ]; then
    sed --regexp-extended --in-place 's|^log.dirs=.+$|log.dirs='"$__KAFKA_LOG_DIRS_PATH"'|' "${__KAFKA_KRAFT_CONFIG_FILE_PATH}"
    __KAFKA_DO_STORAGE_FORMAT=1
fi

if [ "$__KAFKA_DO_STORAGE_FORMAT" = "1" ]; then
    /usr/share/java/kafka/bin/kafka-storage.sh format --standalone -t "$__KAFKA_CLUSTER_ID" -c "$__KAFKA_KRAFT_CONFIG_FILE_PATH"
fi

/usr/share/java/kafka/bin/kafka-server-start.sh "$__KAFKA_KRAFT_CONFIG_FILE_PATH"
